@@ -1,12 +1,13 @@
 package Getopt::Long::Util;
 
-our $DATE = '2015-02-15'; # DATE
-our $VERSION = '0.80'; # VERSION
+our $DATE = '2015-03-24'; # DATE
+our $VERSION = '0.81'; # VERSION
 
 use 5.010001;
 use strict;
 use warnings;
-use experimental 'smartmatch';
+
+use List::Util qw(first);
 
 require Exporter;
 our @ISA       = qw(Exporter);
@@ -97,11 +98,11 @@ sub parse_getopt_long_opt_spec {
 
     if ($res{aliases}) {
         my @als;
-        for (split /\|/, $res{aliases}) {
-            next unless length;
-            next if $_ eq $res{name};
-            next if $_ ~~ @als;
-            push @als, $_;
+        for my $al (split /\|/, $res{aliases}) {
+            next unless length $al;
+            next if $al eq $res{name};
+            next if first {$_ eq $al} @als;
+            push @als, $al;
         }
         $res{opts} = [$res{name}, @als];
     } else {
@@ -285,7 +286,7 @@ Getopt::Long::Util - Utilities for Getopt::Long
 
 =head1 VERSION
 
-This document describes version 0.80 of Getopt::Long::Util (from Perl distribution Getopt-Long-Util), released on 2015-02-15.
+This document describes version 0.81 of Getopt::Long::Util (from Perl distribution Getopt-Long-Util), released on 2015-03-24.
 
 =head1 FUNCTIONS
 
@@ -406,7 +407,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Getopt-Lon
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-Getopt-Long-Util>.
+Source repository is at L<https://github.com/perlancar/perl-Getopt-Long-Util>.
 
 =head1 BUGS
 
